# {{ title }}

This package is part of rudderlabs data-apps to do machine learning tasks

## TODO

**Complete the sentence above to include one phrase about your
package!  Once this is done, delete this to-do!**

### Conda enviroment setup
```
# Create the enviroment
$ conda env create -f environment.yaml

# Activate and install dependencies
$ conda activate py3710_data_apps
$ pip install -r requirement.txt
```
